@@ -22,15 +22,14 @@
 #include "triggerlistview.h"
 #include "elidinglabel.h"
 #include "mouseinputbutton.h"
-
 #include <QApplication>
+#include <QCollator>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QStandardItemModel>
 #include <KCategorizedSortFilterProxyModel>
 #include <KCategoryDrawer>
 #include <KLocalizedString>
-#include <KStringHandler>
 #include <KWidgetItemDelegate>
 
 namespace Palapeli
@@ -42,20 +41,23 @@ namespace Palapeli
 				: KCategorizedSortFilterProxyModel(parent)
 			{
 				setCategorizedModel(true);
+				m_collator.setCaseSensitivity(Qt::CaseSensitive);
 			}
 		protected:
-			virtual int compareCategories(const QModelIndex& left, const QModelIndex& right) const
+			int compareCategories(const QModelIndex& left, const QModelIndex& right) const Q_DECL_OVERRIDE
 			{
 				const int categoryLeft = left.data(KCategorizedSortFilterProxyModel::CategorySortRole).value<int>();
 				const int categoryRight = right.data(KCategorizedSortFilterProxyModel::CategorySortRole).value<int>();
 				return categoryRight - categoryLeft;
 			}
-			virtual bool subSortLessThan(const QModelIndex& left, const QModelIndex& right) const
+			bool subSortLessThan(const QModelIndex& left, const QModelIndex& right) const Q_DECL_OVERRIDE
 			{
 				const QString textLeft = left.data(Qt::DisplayRole).toString();
 				const QString textRight = right.data(Qt::DisplayRole).toString();
-				return KStringHandler::naturalCompare(textLeft, textRight) < 0;
+				return m_collator.compare(textLeft, textRight) < 0;
 			}
+		private:
+			QCollator m_collator;
 	};
 
 	class TriggerListDelegateWidget : public QWidget
@@ -113,22 +115,22 @@ namespace Palapeli
 				m_calculator = new Palapeli::TriggerListDelegateWidget(view);
 				m_calculator->setVisible(false);
 			}
-			virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
+			void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE
 			{
 				Q_UNUSED(index)
 				QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
 			}
-			virtual QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+			QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE
 			{
 				updateItemWidgets(QList<QWidget*>() << m_calculator, option, index);
 				return m_calculator->minimumSizeHint();
 			}
 		protected:
-			virtual QList<QWidget*> createItemWidgets() const
+			QList<QWidget*> createItemWidgets(const QModelIndex &index) const Q_DECL_OVERRIDE
 			{
 				return QList<QWidget*>() << new Palapeli::TriggerListDelegateWidget(itemView());
 			}
-			virtual void updateItemWidgets(QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const
+			void updateItemWidgets(QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const Q_DECL_OVERRIDE
 			{
 				Palapeli::TriggerListDelegateWidget* widget = qobject_cast<Palapeli::TriggerListDelegateWidget*>(widgets[0]);
 				//adjust widget contents
